package de.twenty11.skysail.common;

import java.awt.Color;

public class PresentableHeader {
	
	private final String text;
	private final String link;
	private final String categoryText;
	private final Color categoryColor;
	private final String image;
	
	public static class Builder {
		
		private final String text;
		
		private String link = null;
		private String categoryText = "";
		private Color categoryColor = null;
		private String image = "";
		
        public Builder(String text) {
            this.text = text != null ? text : "---";
        }
		
		public Builder setLink(String link) {this.link = link; return this;}
		
		public Builder setCategoryText(String categoryText) {this.categoryText = categoryText; return this;}
		
		public Builder setCategoryColor(Color categoryColor) {this.categoryColor = categoryColor; return this;}

		public Builder setImage(String image) {this.image = image; return this;}
		
		public PresentableHeader build() {
			return new PresentableHeader(this);
		}

	}

	private PresentableHeader(Builder builder) {
		text = builder.text;
		link = builder.link;
		categoryText = builder.categoryText;
        categoryColor = builder.categoryColor;
        image = builder.image;
	}
	
	public String getText() {
		return text;
	}
	
	public String getLink() {
		return link;
	}
	
	public Color getCategoryColor() {
		return categoryColor;
	}
	
	public String getCategoryText() {
		return categoryText;
	}
	
	public String getImage() {
		return image;
	}

}
